@@ -1,14 +1,18 @@
 import json
+import uuid
 
 
 class Instance(object):
     def __init__(
         self,
+        id: str = None,
         prediction: int = 1,
         confidence: float = 1.0,
         image: str = None,
         metadata: dict = None,
+        properties: dict = None,
     ) -> None:
+        self.id = id or uuid.uuid4().hex
         self.prediction = prediction
         self.confidence = confidence
         self.image = image
@@ -17,7 +21,7 @@ class Instance(object):
             raise ValueError("The field 'metadata' must be a dictionary.")
 
         self.metadata = metadata or {}
-        self.properties = {}
+        self.properties = properties or {}
 
     def has_attribute(self, name: str):
         try:
@@ -94,6 +98,9 @@ class Instance(object):
 
         return attribute_doesnt_exist(name, value)
 
+    def to_dict(self):
+        return self.__dict__
+
     @staticmethod
     def create(data):
         data = data.copy()
