@@ -8,8 +8,18 @@ PIPELINE_MODULE_NAME = "alira.modules.dashboard"
 
 
 class Dashboard(module.Module):
-    def __init__(self, image: str = None, attributes: dict() = None, **kwargs):
-        super().__init__(PIPELINE_MODULE_NAME)
+    def __init__(
+        self,
+        configuration_directory: str,
+        image: str = None,
+        attributes: dict() = None,
+        **kwargs,
+    ):
+        super().__init__(
+            configuration_directory=configuration_directory,
+            module_id=PIPELINE_MODULE_NAME,
+            **kwargs
+        )
 
         self.attributes = attributes
         self.image = image
