@@ -18,11 +18,18 @@ class Flagging(module.Module):
             considered to not flag this instance.
     """
 
-    def __init__(self, threshold: float = 0.6, **kwargs):
-        super().__init__(PIPELINE_MODULE_NAME)
+    def __init__(
+        self,
+        threshold: float = 0.6,
+        **kwargs,
+    ):
+        super().__init__(
+            module_id=PIPELINE_MODULE_NAME,
+            **kwargs,
+        )
         self.threshold = threshold
 
-    def run(self, instance: dict, **kwargs):
+    def run(self, instance: dict):
         confidence = instance.confidence
         return {"flagged": int(confidence < self.threshold)}
 
@@ -61,13 +68,16 @@ class CostSensitiveFlagging(module.Module):
         human_review_cost: float = None,
         **kwargs,
     ):
-        super().__init__(PIPELINE_MODULE_NAME)
+        super().__init__(
+            module_id=PIPELINE_MODULE_NAME,
+            **kwargs,
+        )
 
         self.fp_cost = fp_cost or 0
         self.fn_cost = fn_cost or 0
         self.human_review_cost = human_review_cost or 0
 
-    def run(self, instance: Instance, **kwargs):
+    def run(self, instance: Instance):
         """Processes the supplied instance and returns a field indicating
         whether the instance should be sent for human review together with
         the computed costs.
