@@ -5,12 +5,10 @@ import logging
 import boto3
 import requests
 
-from importlib import import_module
-
 from alira.instance import Instance
-from alira.modules.redis import RedisModule, ServiceException
+from alira.modules.module import Retriable, ServiceException, Module
 
-from botocore.exceptions import ClientError, EndpointConnectionError, InvalidConfigError
+from botocore.exceptions import ClientError, EndpointConnectionError
 
 from twilio.rest import Client
 from twilio.base.exceptions import TwilioRestException
@@ -20,71 +18,56 @@ PIPELINE_EMAIL_MODULE_NAME = "alira.modules.notification.email"
 PIPELINE_SMS_MODULE_NAME = "alira.modules.notification.sms"
 
 
-class Notification(RedisModule):
+class Notification(Retriable):
     def __init__(
         self,
         module_id: str,
-        model_identifier: str,
-        configuration_directory: str,
-        redis_server: str = None,
         filtering: str = None,
+        **kwargs,
     ):
         super().__init__(
             module_id=module_id,
-            model_identifier=model_identifier,
-            configuration_directory=configuration_directory,
-            redis_server=redis_server,
+            **kwargs,
         )
 
         self.filtering = self._load_function(filtering)
 
     def _load_template(self, instance: Instance, template_file):
-        try:
-            with open(
-                os.path.join(self.configuration_directory, template_file),
-                encoding="UTF-8",
-            ) as file:
-                template = file.read()
+        with open(
+            os.path.join(self.configuration_directory, template_file),
+            encoding="UTF-8",
+        ) as file:
+            template = file.read()
 
-            variables_pattern = re.compile(r"\[\[([A-Za-z0-9_.]+)\]\]")
+        variables_pattern = re.compile(r"\[\[([A-Za-z0-9_.]+)\]\]")
 
-            variables = variables_pattern.findall(template)
-            for variable in variables:
-                template = template.replace(
-                    f"[[{variable}]]", str(instance.get_attribute(variable, default=""))
-                )
+        variables = variables_pattern.findall(template)
+        for variable in variables:
+            template = template.replace(
+                f"[[{variable}]]", str(instance.get_attribute(variable, default=""))
+            )
 
-            return template
-
-        except FileNotFoundError:
-            logging.info(f"Template file {template_file} not found")
-            return None
-        except Exception as e:
-            logging.exception(e)
-            return None
+        return template
 
 
 class EmailNotification(Notification):
     def __init__(
         self,
-        model_identifier: str,
         configuration_directory: str,
         sender: str,
         recipients: list,
         subject: str,
         template_html_filename: str,
         template_text_filename: str,
-        redis_server: str = None,
         filtering: str = None,
         provider=None,
         **kwargs,
     ):
         super().__init__(
-            module_id=PIPELINE_EMAIL_MODULE_NAME,
-            model_identifier=model_identifier,
             configuration_directory=configuration_directory,
-            redis_server=redis_server,
+            module_id=PIPELINE_EMAIL_MODULE_NAME,
             filtering=filtering,
+            **kwargs,
         )
 
         self.sender = sender
@@ -111,17 +94,31 @@ class EmailNotification(Notification):
                 "message": "Specified provider is not valid",
             }
 
-        template_text = self._load_template(instance, self.template_text_filename)
-        if not template_text:
-            logging.info("Couldn't load the template text file")
+        try:
+            template_text = self._load_template(instance, self.template_text_filename)
+        except FileNotFoundError as e:
+            logging.exception(e)
+            return {
+                "status": "FAILURE",
+                "message": f"Template file {self.template_text_filename} not found",
+            }
+        except Exception as e:
+            logging.exception(e)
             return {
                 "status": "FAILURE",
                 "message": "Couldn't load the template text file",
             }
 
-        template_html = self._load_template(instance, self.template_html_filename)
-        if not template_html:
-            logging.info("Couldn't load the template html file")
+        try:
+            template_html = self._load_template(instance, self.template_html_filename)
+        except FileNotFoundError as e:
+            logging.exception(e)
+            return {
+                "status": "FAILURE",
+                "message": f"Template file {self.template_html_filename} not found",
+            }
+        except Exception as e:
+            logging.exception(e)
             return {
                 "status": "FAILURE",
                 "message": "Couldn't load the template html file",
@@ -131,28 +128,23 @@ class EmailNotification(Notification):
             f"Sending an email with provider {self.provider.__class__.__name__}"
         )
 
-        arguments = {
-            "sender": self.sender,
-            "recipients": self.recipients,
-            "subject": self.subject,
-            "template_text": template_text,
-            "template_html": template_html,
-        }
-
         try:
-            queue = self.get_redis_queue()
-            if queue:
-                queue.enqueue(self.provider.send_email, **arguments)
-            else:
-                self.provider.send_email(
-                    sender=self.sender,
-                    recipients=self.recipients,
-                    subject=self.subject,
-                    template_text=template_text,
-                    template_html=template_html,
-                )
+            self.provider.send_email(
+                sender=self.sender,
+                recipients=self.recipients,
+                subject=self.subject,
+                template_text=template_text,
+                template_html=template_html,
+            )
+        except ServiceException as e:
+            logging.exception(e)
+            raise e
         except Exception as e:
-            logging.exception("There was an error sending the notification email")
+            logging.exception(e)
+            return {
+                "status": "FAILURE",
+                "message": "Couldn't send email notification",
+            }
 
         return {"status": "SUCCESS"}
 
@@ -160,23 +152,20 @@ class EmailNotification(Notification):
 class SmsNotification(Notification):
     def __init__(
         self,
-        model_identifier: str,
         configuration_directory: str,
         sender: str,
         recipients: list,
         template_text_filename: str,
-        redis_server: str = None,
         filtering: str = None,
         image: str = None,
         provider=None,
         **kwargs,
     ):
         super().__init__(
-            module_id=PIPELINE_SMS_MODULE_NAME,
-            model_identifier=model_identifier,
             configuration_directory=configuration_directory,
-            redis_server=redis_server,
+            module_id=PIPELINE_SMS_MODULE_NAME,
             filtering=filtering,
+            **kwargs,
         )
 
         self.sender = sender
@@ -202,9 +191,16 @@ class SmsNotification(Notification):
                 "message": "Specified provider is not valid",
             }
 
-        template_text = self._load_template(instance, self.template_text_filename)
-        if not template_text:
-            logging.info("Couldn't load the template text file")
+        try:
+            template_text = self._load_template(instance, self.template_text_filename)
+        except FileNotFoundError as e:
+            logging.exception(e)
+            return {
+                "status": "FAILURE",
+                "message": f"Template file {self.template_text_filename} not found",
+            }
+        except Exception as e:
+            logging.exception(e)
             return {
                 "status": "FAILURE",
                 "message": "Couldn't load the template text file",
@@ -215,34 +211,38 @@ class SmsNotification(Notification):
         image_url = instance.get_attribute(self.image, default=None)
         logging.info(f"Image included in message: {image_url}")
 
-        arguments = {
-            "sender": self.sender,
-            "recipients": self.recipients,
-            "message": template_text,
-            "image": image_url,
-        }
-
         try:
-            queue = self.get_redis_queue()
-            if queue:
-                queue.enqueue(self.provider.send_sms, **arguments)
-            else:
-                self.provider.send_sms(**arguments)
+            self.provider.send_sms(
+                sender=self.sender,
+                recipients=self.recipients,
+                message=template_text,
+                image=image_url,
+            )
+        except ServiceException as e:
+            logging.exception(e)
+            raise e
         except Exception as e:
-            logging.exception("There was an error sending the SMS")
+            logging.exception(e)
+            return {
+                "status": "FAILURE",
+                "message": "Couldn't send sms notification",
+            }
 
         return {"status": "SUCCESS"}
 
 
-class SocketIO(object):
+class SocketIO(Module):
     def __init__(
         self,
-        model_identifier: str,
+        pipeline_id: str,
         endpoint: str,
         event: str = "dispatch",
         **kwargs,
     ):
-        self.model_identifier = model_identifier
+        super().__init__(
+            pipeline_id=pipeline_id,
+            **kwargs,
+        )
         self.endpoint = endpoint
         self.event = event
 
@@ -250,7 +250,7 @@ class SocketIO(object):
         payload = {
             "message": "pipeline-new-instance",
             "data": instance.__dict__,
-            "pipeline_id": self.model_identifier,
+            "pipeline_id": self.pipeline_id,
         }
 
         self.emit(self.event, payload)
@@ -262,11 +262,11 @@ class SocketIO(object):
             return
 
         logging.info(
-            f"Sending Socket IO notification to {self.endpoint}. Namespace: {self.model_identifier}"
+            f"Sending Socket IO notification to {self.endpoint}. Namespace: {self.pipeline_id}"
         )
 
         payload["event"] = event
-        payload["namespace"] = self.model_identifier
+        payload["namespace"] = self.pipeline_id
 
         try:
             requests.post(
@@ -308,9 +308,6 @@ class TwilioSmsNotificationProvider(object):
 
             except TwilioRestException as e:
                 raise ServiceException(e)
-            except Exception as e:
-                print(e)
-                logging.exception(e)
 
         return None
 
@@ -399,10 +396,4 @@ class AwsSesEmailNotificationProvider(object):
             client.send_email(**payload)
 
         except EndpointConnectionError as e:
-            logging.exception(e)
-
             raise ServiceException(e)
-        except ClientError as e:
-            logging.exception(e)
-        except Exception as e:
-            logging.exception(e)
