@@ -7,77 +7,16 @@ import os
 from pathlib import Path
 
 from alira.instance import Instance
-from alira.modules.redis import RedisModule, ServiceException
+from alira.modules.module import Retriable, ServiceException
 
 from botocore.exceptions import ClientError, EndpointConnectionError
 
 PIPELINE_MODULE_NAME = "alira.modules.s3"
 
 
-def aws_s3_upload(
-    aws_s3_bucket,
-    aws_s3_public,
-    s3_key,
-    filename,
-    aws_access_key,
-    aws_secret_key,
-    aws_region_name,
-):
-    logging.info(
-        f'Uploading {filename} to bucket "{aws_s3_bucket}" and location {s3_key}...'
-    )
-
-    try:
-        with open(filename, "rb") as file:
-            buffer = file.read()
-    except FileNotFoundError as e:
-        logging.exception(f"There was an error loading the file {filename}")
-        return None
-
-    try:
-        session = boto3.Session(
-            aws_access_key_id=aws_access_key,
-            aws_secret_access_key=aws_secret_key,
-            region_name=aws_region_name,
-        )
-        client = session.client("s3")
-
-        arguments = {"Bucket": aws_s3_bucket, "Key": s3_key, "Body": buffer}
-
-        extension = Path(filename).suffix.lower()
-        content_type = "binary/octet-stream"
-        if extension in [".jpg", ".jpeg"]:
-            content_type = "image/jpeg"
-        elif extension == ".png":
-            content_type = "image/png"
-
-        arguments["ContentType"] = content_type
-
-        if aws_s3_public:
-            arguments["ACL"] = "public-read"
-
-        client.put_object(**arguments)
-
-        s3_location = f"s3://{aws_s3_bucket}/{s3_key}"
-        logging.info(f"Uploaded {filename} to {s3_location}")
-
-        return s3_location
-
-    except EndpointConnectionError as e:
-        logging.exception(e)
-        raise ServiceException(e) from e
-    except ClientError as e:
-        logging.exception(e)
-    except Exception as e:
-        logging.exception(e)
-
-    return None
-
-
-class S3(RedisModule):
+class S3(Retriable):
     def __init__(
         self,
-        model_identifier: str,
         configuration_directory: str,
         aws_s3_bucket: str,
         aws_s3_key_prefix: str,
@@ -87,17 +26,14 @@ class S3(RedisModule):
         aws_secret_key: str = None,
         aws_region_name: str = None,
         autogenerate_name: bool = False,
-        redis_server: str = None,
         filtering: str = None,
         file: str = None,
-        aws_s3_upload_function: callable = aws_s3_upload,
         **kwargs,
     ):
         super().__init__(
-            module_id=module_id or PIPELINE_MODULE_NAME,
-            model_identifier=model_identifier,
             configuration_directory=configuration_directory,
-            redis_server=redis_server,
+            module_id=module_id or PIPELINE_MODULE_NAME,
+            **kwargs,
         )
 
         self.aws_access_key = aws_access_key or os.environ.get(
@@ -122,7 +58,6 @@ class S3(RedisModule):
         self.aws_s3_public = aws_s3_public
 
         self.file = file
-        self.aws_s3_upload_function = aws_s3_upload_function
 
     def run(self, instance: Instance, **kwargs):
         if self.filtering and not self.filtering(instance):
@@ -154,22 +89,18 @@ class S3(RedisModule):
                 "message": f"The file {filename} does not exist",
             }
 
-        arguments = {
-            "aws_s3_bucket": self.aws_s3_bucket,
-            "aws_s3_public": self.aws_s3_public,
-            "s3_key": s3_key,
-            "filename": filename,
-            "aws_access_key": self.aws_access_key,
-            "aws_secret_key": self.aws_secret_key,
-            "aws_region_name": self.aws_region_name,
-        }
+        try:
+            with open(filename, "rb") as file:
+                buffer = file.read()
+        except FileNotFoundError as e:
+            logging.exception(f"There was an error loading the file {filename}")
+            return {
+                "status": "FAILURE",
+                "message": f"There was an error loading the file {filename}",
+            }
 
         try:
-            queue = self.get_redis_queue()
-            if queue:
-                queue.enqueue(self.aws_s3_upload_function, **arguments)
-            else:
-                self.aws_s3_upload_function(**arguments)
+            self.upload(s3_key=s3_key, filename=filename, buffer=buffer)
 
             result = {
                 "status": "SUCCESS",
@@ -182,10 +113,44 @@ class S3(RedisModule):
                 ] = f"https://{self.aws_s3_bucket}.s3.amazonaws.com/{s3_key}"
 
             return result
-
+        except EndpointConnectionError as e:
+            raise e
         except Exception as e:
-            logging.exception("There was an error uploading the image")
+            logging.exception("There was an error uploading the file")
             return {
                 "status": "FAILURE",
-                "message": f"Error uploading the image",
+                "message": "Error uploading the file",
             }
+
+    def upload(self, s3_key, filename, buffer):
+        logging.info(
+            f'Uploading {filename} to bucket "{self.aws_s3_bucket}" and location {s3_key}...'
+        )
+
+        session = boto3.Session(
+            aws_access_key_id=self.aws_access_key,
+            aws_secret_access_key=self.aws_secret_key,
+            region_name=self.aws_region_name,
+        )
+        client = session.client("s3")
+
+        arguments = {"Bucket": self.aws_s3_bucket, "Key": s3_key, "Body": buffer}
+
+        extension = Path(filename).suffix.lower()
+        content_type = "binary/octet-stream"
+        if extension in [".jpg", ".jpeg"]:
+            content_type = "image/jpeg"
+        elif extension == ".png":
+            content_type = "image/png"
+
+        arguments["ContentType"] = content_type
+
+        if self.aws_s3_public:
+            arguments["ACL"] = "public-read"
+
+        client.put_object(**arguments)
+
+        s3_location = f"s3://{self.aws_s3_bucket}/{s3_key}"
+        logging.info(f"Uploaded {filename} to {s3_location}")
+
+        return s3_location
